@tsdotnet/type - v1.2.8
Preparing search index...
type
isNullOrUndefined
Function isNullOrUndefined
isNullOrUndefined
(
value
:
unknown
)
:
value
is
null
|
undefined
Returns true if the value parameter is null or undefined.
Parameters
value
:
unknown
Returns
value
is
null
|
undefined
Settings
Member Visibility
Protected
Inherited
Theme
OS
Light
Dark
@tsdotnet/type - v1.2.8
Loading...
Returns true if the value parameter is null or undefined.